// STL headers
#if __has_include("cstdlib")
#include <cstdlib>
#endif
#if __has_include("csignal")
#include <csignal>
#endif
#if __has_include("csetjmp")
#include <csetjmp>
#endif
#if __has_include("cstdarg")
#include <cstdarg>
#endif
#if __has_include("typeinfo")
#include <typeinfo>
#endif
#if __has_include("typeindex")
#include <typeindex>
#endif
#if __has_include("type_traits")
#include <type_traits>
#endif
#if __has_include("bitset")
#include <bitset>
#endif
#if __has_include("functional")
#include <functional>
#endif
#if __has_include("utility")
#include <utility>
#endif
#if __has_include("ctime")
#include <ctime>
#endif
#if __has_include("chrono")
#include <chrono>
#endif
#if __has_include("cstddef")
#include <cstddef>
#endif
#if __has_include("initializer_list")
#include <initializer_list>
#endif
#if __has_include("tuple")
#include <tuple>
#endif
#if __has_include("new")
#include <new>
#endif
#if __has_include("memory")
#include <memory>
#endif
#if __has_include("scoped_allocator")
#include <scoped_allocator>
#endif
#if __has_include("climits")
#include <climits>
#endif
#if __has_include("cfloat")
#include <cfloat>
#endif
#if __has_include("cstdint")
#include <cstdint>
#endif
#if __has_include("cinttypes")
#include <cinttypes>
#endif
#if __has_include("limits")
#include <limits>
#endif
#if __has_include("exception")
#include <exception>
#endif
#if __has_include("stdexcept")
#include <stdexcept>
#endif
#if __has_include("cassert")
#include <cassert>
#endif
#if __has_include("system_error")
#include <system_error>
#endif
#if __has_include("cerrno")
#include <cerrno>
#endif
#if __has_include("cctype")
#include <cctype>
#endif
#if __has_include("cwctype")
#include <cwctype>
#endif
#if __has_include("cstring")
#include <cstring>
#endif
#if __has_include("cwchar")
#include <cwchar>
#endif
#if __has_include("cuchar")
#include <cuchar>
#endif
#if __has_include("string")
#include <string>
#endif
#if __has_include("array")
#include <array>
#endif
#if __has_include("vector")
#include <vector>
#endif
#if __has_include("deque")
#include <deque>
#endif
#if __has_include("list")
#include <list>
#endif
#if __has_include("forward_list")
#include <forward_list>
#endif
#if __has_include("set")
#include <set>
#endif
#if __has_include("map")
#include <map>
#endif
#if __has_include("unordered_set")
#include <unordered_set>
#endif
#if __has_include("unordered_map")
#include <unordered_map>
#endif
#if __has_include("stack")
#include <stack>
#endif
#if __has_include("queue")
#include <queue>
#endif
#if __has_include("algorithm")
#include <algorithm>
#endif
#if __has_include("iterator")
#include <iterator>
#endif
#if __has_include("cmath")
#include <cmath>
#endif
#if __has_include("complex")
#include <complex>
#endif
#if __has_include("random")
#include <random>
#endif
#if __has_include("numeric")
#include <numeric>
#endif
#if __has_include("ratio")
#include <ratio>
#endif
#if __has_include("cfenv")
#include <cfenv>
#endif
#if __has_include("iosfwd")
#include <iosfwd>
#endif
#if __has_include("ios")
#include <ios>
#endif
#if __has_include("istream")
#include <istream>
#endif
#if __has_include("ostream")
#include <ostream>
#endif
#if __has_include("iostream")
#include <iostream>
#endif
#if __has_include("fstream")
#include <fstream>
#endif
#if __has_include("sstream")
#include <sstream>
#endif
#if __has_include("iomanip")
#include <iomanip>
#endif
#if __has_include("streambuf")
#include <streambuf>
#endif
#if __has_include("cstdio")
#include <cstdio>
#endif
#if __has_include("locale")
#include <locale>
#endif
#if __has_include("clocale")
#include <clocale>
#endif
#if __has_include("codecvt")
#include <codecvt>
#endif
#if __has_include("atomic")
#include <atomic>
#endif
#if __has_include("thread")
#include <thread>
#endif
#if __has_include("mutex")
#include <mutex>
#endif
#if __has_include("future")
#include <future>
#endif
#if __has_include("condition_variable")
#include <condition_variable>
#endif
#if __has_include("ciso646")
#include <ciso646>
#endif
#if __has_include("ccomplex")
#include <ccomplex>
#endif
#if __has_include("ctgmath")
#include <ctgmath>
#endif
#if __has_include("regex")
#include <regex>
#endif
#if __has_include("cstdbool")
#include <cstdbool>
#endif
// treat regex separately
#if __has_include("regex") && !defined __APPLE__
#include <regex>
#endif
// STL Deprecated headers
#define _BACKWARD_BACKWARD_WARNING_H
#pragma clang diagnostic push
#pragma GCC diagnostic ignored "-Wdeprecated"
#if __has_include("strstream")
#include <strstream>
#endif
#pragma clang diagnostic pop
#undef _BACKWARD_BACKWARD_WARNING_H
#include "etc/cling/Interpreter/DynamicLookupRuntimeUniverse.h"
#include "etc/cling/Interpreter/DynamicLookupLifetimeHandler.h"
#include "etc/cling/Interpreter/Exception.h"
#include "etc/cling/Interpreter/RuntimePrintValue.h"
#include "etc/cling/Interpreter/RuntimeUniverse.h"
#include "etc/cling/Interpreter/RuntimeOptions.h"
#include "etc/cling/Interpreter/Value.h"
#include "etc/cling/Interpreter/Visibility.h"
#define ROOFIT_BUILDS_ITSELF
// ./core/clingutils/G__dequeDict.cxx
#include "deque"
// ./core/clingutils/G__forward_listDict.cxx
#include "forward_list"
// ./core/clingutils/G__listDict.cxx
#include "list"
// ./core/clingutils/G__vectorDict.cxx
#include "vector"
// ./core/clingutils/G__setDict.cxx
#include "set"
// ./core/clingutils/G__multimap2Dict.cxx
#include "map"
// ./core/clingutils/G__multisetDict.cxx
#include "set"
// ./core/clingutils/G__multimapDict.cxx
#include "map"
// ./core/clingutils/G__map2Dict.cxx
#include "map"
// ./core/clingutils/G__unordered_setDict.cxx
#include "unordered_set"
// ./core/clingutils/G__unordered_multisetDict.cxx
#include "unordered_set"
// ./core/clingutils/G__mapDict.cxx
#include "map"
// ./core/clingutils/G__valarrayDict.cxx
#include "valarray"
// ./core/clingutils/G__unordered_multimapDict.cxx
#include "unordered_map"
// ./core/clingutils/G__complexDict.cxx
#include "root_std_complex.h"
// ./core/clingutils/G__unordered_mapDict.cxx
#include "unordered_map"
// ./core/imt/G__Imt.cxx
#include "ROOT/TTaskGroup.hxx"
#include "ROOT/RTaskArena.hxx"
#include "ROOT/RSlotStack.hxx"
#include "ROOT/TExecutor.hxx"
#include "ROOT/TThreadExecutor.hxx"
// ./core/multiproc/G__MultiProc.cxx
#include "MPCode.h"
#include "MPSendRecv.h"
#include "PoolUtils.h"
#include "TMPClient.h"
#include "TMPWorker.h"
#include "TMPWorkerExecutor.h"
#include "TProcPool.h"
#include "ROOT/TProcessExecutor.hxx"
// ./core/rint/G__Rint.cxx
#include "TRint.h"
#include "TTabCom.h"
// ./core/thread/G__Thread.cxx
#include "TPosixCondition.h"
#include "TPosixMutex.h"
#include "TPosixThread.h"
#include "TPosixThreadFactory.h"
#include "PosixThreadInc.h"
#include "TAtomicCount.h"
#include "TCondition.h"
#include "TConditionImp.h"
#include "TMutex.h"
#include "TMutexImp.h"
#include "TRWLock.h"
#include "TSemaphore.h"
#include "TThreadFactory.h"
#include "TThread.h"
#include "TThreadImp.h"
#include "TThreadPool.h"
#include "ROOT/RConcurrentHashColl.hxx"
#include "ROOT/TRWSpinLock.hxx"
#include "ROOT/TSpinMutex.hxx"
#include "ROOT/TThreadedObject.hxx"
// ./math/mathcore/G__MathCore.cxx
#include "Fit/BasicFCN.h"
#include "Fit/BinData.h"
#include "Fit/Chi2FCN.h"
#include "Fit/DataOptions.h"
#include "Fit/DataRange.h"
#include "Fit/FcnAdapter.h"
#include "Fit/FitConfig.h"
#include "Fit/FitData.h"
#include "Fit/FitExecutionPolicy.h"
#include "Fit/FitResult.h"
#include "Fit/FitUtil.h"
#include "Fit/Fitter.h"
#include "Fit/LogLikelihoodFCN.h"
#include "Fit/ParameterSettings.h"
#include "Fit/PoissonLikelihoodFCN.h"
#include "Fit/SparseData.h"
#include "Fit/UnBinData.h"
#include "Math/AdaptiveIntegratorMultiDim.h"
#include "Math/AllIntegrationTypes.h"
#include "Math/BasicMinimizer.h"
#include "Math/BrentMethods.h"
#include "Math/BrentMinimizer1D.h"
#include "Math/BrentRootFinder.h"
#include "Math/ChebyshevPol.h"
#include "Math/Delaunay2D.h"
#include "Math/DistFuncMathCore.h"
#include "Math/DistSampler.h"
#include "Math/DistSamplerOptions.h"
#include "Math/Error.h"
#include "Math/Factory.h"
#include "Math/FitMethodFunction.h"
#include "Math/Functor.h"
#include "Math/GaussIntegrator.h"
#include "Math/GaussLegendreIntegrator.h"
#include "Math/GenAlgoOptions.h"
#include "Math/GoFTest.h"
#include "Math/IFunction.h"
#include "Math/IFunctionfwd.h"
#include "Math/IMinimizer1D.h"
#include "Math/IOptions.h"
#include "Math/IParamFunction.h"
#include "Math/IParamFunctionfwd.h"
#include "Math/IRootFinderMethod.h"
#include "Math/Integrator.h"
#include "Math/IntegratorMultiDim.h"
#include "Math/IntegratorOptions.h"
#include "Math/KDTree.h"
#include "Math/LCGEngine.h"
#include "Math/Math.h"
#include "Math/MersenneTwisterEngine.h"
#include "Math/MinimTransformFunction.h"
#include "Math/MinimTransformVariable.h"
#include "Math/Minimizer.h"
#include "Math/MinimizerOptions.h"
#include "Math/MinimizerVariableTransformation.h"
#include "Math/MixMaxEngine.h"
#include "Math/MultiDimParamFunctionAdapter.h"
#include "Math/OneDimFunctionAdapter.h"
#include "Math/ParamFunctor.h"
#include "Math/PdfFuncMathCore.h"
#include "Math/ProbFuncMathCore.h"
#include "Math/QuantFuncMathCore.h"
#include "Math/Random.h"
#include "Math/RandomFunctions.h"
#include "Math/RanluxppEngine.h"
#include "Math/RichardsonDerivator.h"
#include "Math/RootFinder.h"
#include "Math/SpecFuncMathCore.h"
#include "Math/StdEngine.h"
#include "Math/TDataPoint.h"
#include "Math/TDataPointN.h"
#include "Math/TRandomEngine.h"
#include "Math/Types.h"
#include "Math/Util.h"
#include "Math/VirtualIntegrator.h"
#include "Math/WrappedFunction.h"
#include "Math/WrappedParamFunction.h"
#include "TComplex.h"
#include "TKDTree.h"
#include "TKDTreeBinning.h"
#include "TMath.h"
#include "TRandom.h"
#include "TRandom1.h"
#include "TRandom2.h"
#include "TRandom3.h"
#include "TRandomGen.h"
#include "TStatistic.h"
#include "VectorizedTMath.h"
// ./math/mathmore/G__MathMore.cxx
#include "Math/ChebyshevApprox.h"
#include "Math/Derivator.h"
#include "Math/DistFuncMathMore.h"
#include "Math/GSLIntegrator.h"
#include "Math/GSLMCIntegrator.h"
#include "Math/GSLMinimizer.h"
#include "Math/GSLMinimizer1D.h"
#include "Math/GSLMultiRootFinder.h"
#include "Math/GSLNLSMinimizer.h"
#include "Math/GSLQuasiRandom.h"
#include "Math/GSLRandom.h"
#include "Math/GSLRandomFunctions.h"
#include "Math/GSLRndmEngines.h"
#include "Math/GSLRootFinder.h"
#include "Math/GSLRootFinderDeriv.h"
#include "Math/GSLSimAnMinimizer.h"
#include "Math/InterpolationTypes.h"
#include "Math/Interpolator.h"
#include "Math/MCParameters.h"
#include "Math/PdfFuncMathMore.h"
#include "Math/Polynomial.h"
#include "Math/ParamFunction.h"
#include "Math/QuasiRandom.h"
#include "Math/RootFinderAlgorithms.h"
#include "Math/SpecFuncMathMore.h"
#include "Math/Vavilov.h"
#include "Math/VavilovAccurate.h"
#include "Math/VavilovAccurateCdf.h"
#include "Math/VavilovAccuratePdf.h"
#include "Math/VavilovAccurateQuantile.h"
#include "Math/VavilovFast.h"
// ./math/matrix/G__Matrix.cxx
#include "TDecompBK.h"
#include "TDecompBase.h"
#include "TDecompChol.h"
#include "TDecompLU.h"
#include "TDecompQRH.h"
#include "TDecompSVD.h"
#include "TDecompSparse.h"
#include "TMatrix.h"
#include "TMatrixD.h"
#include "TMatrixDBase.h"
#include "TMatrixDBasefwd.h"
#include "TMatrixDEigen.h"
#include "TMatrixDLazy.h"
#include "TMatrixDSparse.h"
#include "TMatrixDSparsefwd.h"
#include "TMatrixDSym.h"
#include "TMatrixDSymEigen.h"
#include "TMatrixDSymfwd.h"
#include "TMatrixDUtils.h"
#include "TMatrixDUtilsfwd.h"
#include "TMatrixDfwd.h"
#include "TMatrixF.h"
#include "TMatrixFBase.h"
#include "TMatrixFBasefwd.h"
#include "TMatrixFLazy.h"
#include "TMatrixFSparse.h"
#include "TMatrixFSparsefwd.h"
#include "TMatrixFSym.h"
#include "TMatrixFSymfwd.h"
#include "TMatrixFUtils.h"
#include "TMatrixFUtilsfwd.h"
#include "TMatrixFfwd.h"
#include "TMatrixT.h"
#include "TMatrixTBase.h"
#include "TMatrixTCramerInv.h"
#include "TMatrixTLazy.h"
#include "TMatrixTSparse.h"
#include "TMatrixTSym.h"
#include "TMatrixTSymCramerInv.h"
#include "TMatrixTUtils.h"
#include "TVector.h"
#include "TVectorD.h"
#include "TVectorDfwd.h"
#include "TVectorF.h"
#include "TVectorFfwd.h"
#include "TVectorT.h"
#include "TVectorfwd.h"
// ./math/minuit/G__Minuit.cxx
#include "TFitter.h"
#include "TLinearFitter.h"
#include "TLinearMinimizer.h"
#include "TMinuit.h"
#include "TMinuitMinimizer.h"
// ./math/minuit2/G__Minuit2.cxx
#include "Minuit2/AnalyticalGradientCalculator.h"
#include "Minuit2/BFGSErrorUpdator.h"
#include "Minuit2/CombinedMinimizer.h"
#include "Minuit2/CombinedMinimumBuilder.h"
#include "Minuit2/ContoursError.h"
#include "Minuit2/DavidonErrorUpdator.h"
#include "Minuit2/ExternalInternalGradientCalculator.h"
#include "Minuit2/FCNAdapter.h"
#include "Minuit2/FCNBase.h"
#include "Minuit2/FCNGradAdapter.h"
#include "Minuit2/FCNGradientBase.h"
#include "Minuit2/FumiliBuilder.h"
#include "Minuit2/FumiliChi2FCN.h"
#include "Minuit2/FumiliErrorUpdator.h"
#include "Minuit2/FumiliFCNAdapter.h"
#include "Minuit2/FumiliFCNBase.h"
#include "Minuit2/FumiliGradientCalculator.h"
#include "Minuit2/FumiliMaximumLikelihoodFCN.h"
#include "Minuit2/FumiliMinimizer.h"
#include "Minuit2/FumiliStandardChi2FCN.h"
#include "Minuit2/FumiliStandardMaximumLikelihoodFCN.h"
#include "Minuit2/FunctionGradient.h"
#include "Minuit2/FunctionMinimum.h"
#include "Minuit2/GradientCalculator.h"
#include "Minuit2/HessianGradientCalculator.h"
#include "Minuit2/InitialGradientCalculator.h"
#include "Minuit2/MinimumBuilder.h"
#include "Minuit2/MinimumError.h"
#include "Minuit2/MinimumErrorUpdator.h"
#include "Minuit2/MinimumParameters.h"
#include "Minuit2/MinimumSeed.h"
#include "Minuit2/MinimumSeedGenerator.h"
#include "Minuit2/MinimumState.h"
#include "Minuit2/MinosError.h"
#include "Minuit2/Minuit2Minimizer.h"
#include "Minuit2/MinuitParameter.h"
#include "Minuit2/MnApplication.h"
#include "Minuit2/MnConfig.h"
#include "Minuit2/MnContours.h"
#include "Minuit2/MnCovarianceSqueeze.h"
#include "Minuit2/MnCross.h"
#include "Minuit2/MnEigen.h"
#include "Minuit2/MnFcn.h"
#include "Minuit2/MnFumiliMinimize.h"
#include "Minuit2/MnFunctionCross.h"
#include "Minuit2/MnGlobalCorrelationCoeff.h"
#include "Minuit2/MnHesse.h"
#include "Minuit2/MnLineSearch.h"
#include "Minuit2/MnMachinePrecision.h"
#include "Minuit2/MnMatrix.h"
#include "Minuit2/MnMatrixfwd.h"
#include "Minuit2/MnMigrad.h"
#include "Minuit2/MnMinimize.h"
#include "Minuit2/MnMinos.h"
#include "Minuit2/MnParabola.h"
#include "Minuit2/MnParabolaFactory.h"
#include "Minuit2/MnParabolaPoint.h"
#include "Minuit2/MnParameterScan.h"
#include "Minuit2/MnPlot.h"
#include "Minuit2/MnPosDef.h"
#include "Minuit2/MnPrint.h"
#include "Minuit2/MnScan.h"
#include "Minuit2/MnSeedGenerator.h"
#include "Minuit2/MnSimplex.h"
#include "Minuit2/MnStrategy.h"
#include "Minuit2/MnTiny.h"
#include "Minuit2/MnTraceObject.h"
#include "Minuit2/MnUserCovariance.h"
#include "Minuit2/MnUserFcn.h"
#include "Minuit2/MnUserParameterState.h"
#include "Minuit2/MnUserParameters.h"
#include "Minuit2/MnUserTransformation.h"
#include "Minuit2/ModularFunctionMinimizer.h"
#include "Minuit2/NegativeG2LineSearch.h"
#include "Minuit2/Numerical2PGradientCalculator.h"
#include "Minuit2/NumericalDerivator.h"
#include "Minuit2/ParametricFunction.h"
#include "Minuit2/ScanBuilder.h"
#include "Minuit2/ScanMinimizer.h"
#include "Minuit2/SimplexBuilder.h"
#include "Minuit2/SimplexMinimizer.h"
#include "Minuit2/SimplexParameters.h"
#include "Minuit2/SimplexSeedGenerator.h"
#include "Minuit2/SinParameterTransformation.h"
#include "Minuit2/SqrtLowParameterTransformation.h"
#include "Minuit2/SqrtUpParameterTransformation.h"
#include "Minuit2/VariableMetricBuilder.h"
#include "Minuit2/VariableMetricEDMEstimator.h"
#include "Minuit2/VariableMetricMinimizer.h"
#include "TMinuit2TraceObject.h"
// ./math/physics/G__Physics.cxx
#include "TFeldmanCousins.h"
#include "TGenPhaseSpace.h"
#include "TLorentzRotation.h"
#include "TLorentzVector.h"
#include "TQuaternion.h"
#include "TRobustEstimator.h"
#include "TRolke.h"
#include "TRotation.h"
#include "TVector2.h"
#include "TVector3.h"
// ./math/smatrix/G__Smatrix32.cxx
#include "Math/SMatrix.h"
#include "Math/SMatrixDfwd.h"
#include "Math/SMatrixFfwd.h"
#include "Math/SVector.h"
// ./math/smatrix/G__Smatrix.cxx
#include "Math/BinaryOperators.h"
#include "Math/BinaryOpPolicy.h"
#include "Math/CholeskyDecomp.h"
#include "Math/Dfact.h"
#include "Math/Dfactir.h"
#include "Math/Dfinv.h"
#include "Math/Dinv.h"
#include "Math/Dsfact.h"
#include "Math/Dsinv.h"
#include "Math/Expression.h"
#include "Math/Functions.h"
#include "Math/HelperOps.h"
#include "Math/MatrixFunctions.h"
#include "Math/MatrixRepresentationsStatic.h"
#include "Math/MConfig.h"
#include "Math/SMatrixDfwd.h"
#include "Math/SMatrixFfwd.h"
#include "Math/SMatrix.h"
#include "Math/StaticCheck.h"
#include "Math/SVector.h"
#include "Math/UnaryOperators.h"
// ./math/genvector/G__GenVector32.cxx
#include "Math/Point2D.h"
#include "Math/Point3D.h"
#include "Math/Vector2D.h"
#include "Math/Vector3D.h"
#include "Math/Vector4D.h"
// ./math/genvector/G__GenVector.cxx
#include "Math/AxisAngle.h"
#include "Math/Boost.h"
#include "Math/BoostX.h"
#include "Math/BoostY.h"
#include "Math/BoostZ.h"
#include "Math/Cartesian2D.h"
#include "Math/Cartesian3D.h"
#include "Math/Cylindrical3D.h"
#include "Math/CylindricalEta3D.h"
#include "Math/DisplacementVector2D.h"
#include "Math/DisplacementVector3D.h"
#include "Math/EulerAngles.h"
#include "Math/GenVector/3DConversions.h"
#include "Math/GenVector/3DDistances.h"
#include "Math/GenVector/AxisAnglefwd.h"
#include "Math/GenVector/AxisAngle.h"
#include "Math/GenVector/BitReproducible.h"
#include "Math/GenVector/Boostfwd.h"
#include "Math/GenVector/Boost.h"
#include "Math/GenVector/BoostXfwd.h"
#include "Math/GenVector/BoostX.h"
#include "Math/GenVector/BoostYfwd.h"
#include "Math/GenVector/BoostY.h"
#include "Math/GenVector/BoostZfwd.h"
#include "Math/GenVector/BoostZ.h"
#include "Math/GenVector/Cartesian2Dfwd.h"
#include "Math/GenVector/Cartesian2D.h"
#include "Math/GenVector/Cartesian3Dfwd.h"
#include "Math/GenVector/Cartesian3D.h"
#include "Math/GenVector/CoordinateSystemTags.h"
#include "Math/GenVector/Cylindrical3Dfwd.h"
#include "Math/GenVector/Cylindrical3D.h"
#include "Math/GenVector/CylindricalEta3Dfwd.h"
#include "Math/GenVector/CylindricalEta3D.h"
#include "Math/GenVector/DisplacementVector2Dfwd.h"
#include "Math/GenVector/DisplacementVector2D.h"
#include "Math/GenVector/DisplacementVector3Dfwd.h"
#include "Math/GenVector/DisplacementVector3D.h"
#include "Math/GenVector/eta.h"
#include "Math/GenVector/etaMax.h"
#include "Math/GenVector/EulerAnglesfwd.h"
#include "Math/GenVector/EulerAngles.h"
#include "Math/GenVector/GenVector_exception.h"
#include "Math/GenVector/GenVectorIO.h"
#include "Math/GenVector/LorentzRotationfwd.h"
#include "Math/GenVector/LorentzRotation.h"
#include "Math/GenVector/LorentzVectorfwd.h"
#include "Math/GenVector/LorentzVector.h"
#include "Math/GenVector/Plane3D.h"
#include "Math/GenVector/Polar2Dfwd.h"
#include "Math/GenVector/Polar2D.h"
#include "Math/GenVector/Polar3Dfwd.h"
#include "Math/GenVector/Polar3D.h"
#include "Math/GenVector/PositionVector2Dfwd.h"
#include "Math/GenVector/PositionVector2D.h"
#include "Math/GenVector/PositionVector3Dfwd.h"
#include "Math/GenVector/PositionVector3D.h"
#include "Math/GenVector/PtEtaPhiE4Dfwd.h"
#include "Math/GenVector/PtEtaPhiE4D.h"
#include "Math/GenVector/PtEtaPhiM4Dfwd.h"
#include "Math/GenVector/PtEtaPhiM4D.h"
#include "Math/GenVector/PxPyPzE4Dfwd.h"
#include "Math/GenVector/PxPyPzE4D.h"
#include "Math/GenVector/PxPyPzM4Dfwd.h"
#include "Math/GenVector/PxPyPzM4D.h"
#include "Math/GenVector/Quaternionfwd.h"
#include "Math/GenVector/Quaternion.h"
#include "Math/GenVector/Rotation3Dfwd.h"
#include "Math/GenVector/Rotation3D.h"
#include "Math/GenVector/RotationXfwd.h"
#include "Math/GenVector/RotationX.h"
#include "Math/GenVector/RotationYfwd.h"
#include "Math/GenVector/RotationY.h"
#include "Math/GenVector/RotationZfwd.h"
#include "Math/GenVector/RotationZ.h"
#include "Math/GenVector/RotationZYXfwd.h"
#include "Math/GenVector/RotationZYX.h"
#include "Math/GenVector/Transform3D.h"
#include "Math/GenVector/Translation3D.h"
#include "Math/GenVector/VectorUtil.h"
#include "Math/LorentzRotation.h"
#include "Math/LorentzVector.h"
#include "Math/Plane3D.h"
#include "Math/Point2Dfwd.h"
#include "Math/Point2D.h"
#include "Math/Point3Dfwd.h"
#include "Math/Point3D.h"
#include "Math/Polar2D.h"
#include "Math/Polar3D.h"
#include "Math/PositionVector2D.h"
#include "Math/PositionVector3D.h"
#include "Math/PtEtaPhiE4D.h"
#include "Math/PtEtaPhiM4D.h"
#include "Math/PxPyPzE4D.h"
#include "Math/PxPyPzM4D.h"
#include "Math/Quaternion.h"
#include "Math/Rotation3D.h"
#include "Math/RotationX.h"
#include "Math/RotationY.h"
#include "Math/RotationZ.h"
#include "Math/RotationZYX.h"
#include "Math/Transform3D.h"
#include "Math/Translation3D.h"
#include "Math/Vector2Dfwd.h"
#include "Math/Vector2D.h"
#include "Math/Vector3Dfwd.h"
#include "Math/Vector3D.h"
#include "Math/Vector4Dfwd.h"
#include "Math/Vector4D.h"
#include "Math/VectorUtil.h"
// ./math/genetic/G__Genetic.cxx
#include "Math/GeneticMinimizer.h"
// ./math/vecops/G__ROOTVecOps.cxx
#include "ROOT/RVec.hxx"
// ./hist/hist/G__Hist.cxx
#include "Foption.h"
#include "HFitInterface.h"
#include "TAxis.h"
#include "TAxisModLab.h"
#include "TBackCompFitter.h"
#include "TBinomialEfficiencyFitter.h"
#include "TConfidenceLevel.h"
#include "TEfficiency.h"
#include "TF12.h"
#include "TF1AbsComposition.h"
#include "TF1Convolution.h"
#include "TF1.h"
#include "TF1NormSum.h"
#include "TF2.h"
#include "TF3.h"
#include "TFitResult.h"
#include "TFitResultPtr.h"
#include "TFormula.h"
#include "TFractionFitter.h"
#include "THistRange.h"
#include "TGraph2DErrors.h"
#include "TGraph2DAsymmErrors.h"
#include "TGraph2D.h"
#include "TGraphAsymmErrors.h"
#include "TGraphMultiErrors.h"
#include "TGraphBentErrors.h"
#include "TGraphDelaunay2D.h"
#include "TGraphDelaunay.h"
#include "TGraphErrors.h"
#include "TGraph.h"
#include "TGraphSmooth.h"
#include "TGraphTime.h"
#include "TScatter.h"
#include "TH1C.h"
#include "TH1D.h"
#include "TH1F.h"
#include "TH1.h"
#include "TH1I.h"
#include "TH1K.h"
#include "TH1L.h"
#include "TH1S.h"
#include "TH2C.h"
#include "TH2D.h"
#include "TH2F.h"
#include "TH2.h"
#include "TH2I.h"
#include "TH2L.h"
#include "TH2Poly.h"
#include "TH2S.h"
#include "TH3C.h"
#include "TH3D.h"
#include "TH3F.h"
#include "TH3.h"
#include "TH3I.h"
#include "TH3L.h"
#include "TH3S.h"
#include "THLimitsFinder.h"
#include "THnBase.h"
#include "THnChain.h"
#include "THn.h"
#include "THnSparse.h"
#include "THnSparse_Internal.h"
#include "THStack.h"
#include "TKDE.h"
#include "TLimitDataSource.h"
#include "TLimit.h"
#include "TMultiDimFit.h"
#include "TMultiGraph.h"
#include "TNDArray.h"
#include "TPolyMarker.h"
#include "TPrincipal.h"
#include "TProfile2D.h"
#include "TProfile2Poly.h"
#include "TProfile3D.h"
#include "TProfile.h"
#include "TSpline.h"
#include "TSVDUnfold.h"
#include "TVirtualFitter.h"
#include "TVirtualGraphPainter.h"
#include "TVirtualHistPainter.h"
#include "TVirtualPaveStats.h"
#include "Math/WrappedMultiTF1.h"
#include "Math/WrappedTF1.h"
#include "v5/TF1Data.h"
#include "v5/TFormula.h"
#include "v5/TFormulaPrimitive.h"
// ./hist/histpainter/G__HistPainter.cxx
#include "Hoption.h"
#include "Hparam.h"
#include "TGraph2DPainter.h"
#include "TGraphPainter.h"
#include "THistPainter.h"
#include "TPaletteAxis.h"
// ./hist/spectrum/G__Spectrum.cxx
#include "TSpectrum.h"
#include "TSpectrum2.h"
#include "TSpectrum2Fit.h"
#include "TSpectrum2Transform.h"
#include "TSpectrum3.h"
#include "TSpectrumFit.h"
#include "TSpectrumTransform.h"
// ./hist/spectrumpainter/G__SpectrumPainter.cxx
#include "TSpectrum2Painter.h"
// ./hist/hbook/G__Hbook.cxx
#include "THbookBranch.h"
#include "THbookFile.h"
#include "THbookKey.h"
#include "THbookTree.h"
// ./tree/tree/G__Tree.cxx
#include "TBasket.h"
#include "TBasketSQL.h"
#include "TBranchBrowsable.h"
#include "TBranchCacheInfo.h"
#include "TBranchClones.h"
#include "TBranchElement.h"
#include "TBranch.h"
#include "TBranchObject.h"
#include "TBranchRef.h"
#include "TBranchSTL.h"
#include "TBufferSQL.h"
#include "TChainElement.h"
#include "TChain.h"
#include "TCut.h"
#include "TEntryListArray.h"
#include "TEntryListBlock.h"
#include "TEntryListFromFile.h"
#include "TEntryList.h"
#include "TEventList.h"
#include "TFriendElement.h"
#include "TIndArray.h"
#include "TLeafB.h"
#include "TLeafC.h"
#include "TLeafD.h"
#include "TLeafD32.h"
#include "TLeafElement.h"
#include "TLeafF.h"
#include "TLeafF16.h"
#include "TLeaf.h"
#include "TLeafI.h"
#include "TLeafL.h"
#include "TLeafG.h"
#include "TLeafObject.h"
#include "TLeafO.h"
#include "TLeafS.h"
#include "TNtupleD.h"
#include "TNtuple.h"
#include "TQueryResult.h"
#include "TreeUtils.h"
#include "TSelector.h"
#include "TSelectorList.h"
#include "TSelectorScalar.h"
#include "TTreeCache.h"
#include "TTreeCacheUnzip.h"
#include "TTreeCloner.h"
#include "TTree.h"
#include "TTreeResult.h"
#include "TTreeRow.h"
#include "TTreeSQL.h"
#include "TVirtualIndex.h"
#include "TVirtualTreePlayer.h"
#include "ROOT/InternalTreeUtils.hxx"
#include "ROOT/RFriendInfo.hxx"
#include "ROOT/TIOFeatures.hxx"
// ./tree/treeplayer/G__TreePlayer.cxx
#include "ROOT/TTreeReaderFast.hxx"
#include "ROOT/TTreeReaderValueFast.hxx"
#include "TBranchProxyClassDescriptor.h"
#include "TBranchProxyDescriptor.h"
#include "TBranchProxyDirector.h"
#include "TBranchProxy.h"
#include "TChainIndex.h"
#include "TFileDrawMap.h"
#include "TFormLeafInfo.h"
#include "TFormLeafInfoReference.h"
#include "TFriendProxyDescriptor.h"
#include "TFriendProxy.h"
#include "TRefArrayProxy.h"
#include "TRefProxy.h"
#include "TSelectorDraw.h"
#include "TSelectorEntries.h"
#include "TSimpleAnalysis.h"
#include "TTreeDrawArgsParser.h"
#include "TTreeFormula.h"
#include "TTreeFormulaManager.h"
#include "TTreeGeneratorBase.h"
#include "TTreeIndex.h"
#include "TTreePerfStats.h"
#include "TTreePlayer.h"
#include "TTreeProxyGenerator.h"
#include "TTreeReaderArray.h"
#include "TTreeReaderGenerator.h"
#include "TTreeReader.h"
#include "TTreeReaderUtils.h"
#include "TTreeReaderValue.h"
#include "TTreeTableInterface.h"
#include "TMPWorkerTree.h"
#include "ROOT/TTreeProcessorMP.hxx"
#include "ROOT/TTreeProcessorMT.hxx"
// ./tree/treeviewer/G__TreeViewer.cxx
#include "HelpTextTV.h"
#include "TGTreeTable.h"
#include "TParallelCoordEditor.h"
#include "TParallelCoord.h"
#include "TParallelCoordRange.h"
#include "TParallelCoordVar.h"
#include "TSpiderEditor.h"
#include "TSpider.h"
#include "TTreeViewer.h"
#include "TTVLVContainer.h"
#include "TTVSession.h"
// ./tree/webviewer/G__ROOTTreeViewer.cxx
#include "ROOT/RTreeViewer.hxx"
// ./tree/dataframe/G__ROOTDataFrame.cxx
#include "ROOT/RCsvDS.hxx"
#include "ROOT/RVecDS.hxx"
#include "ROOT/RDataFrame.hxx"
#include "ROOT/RDataSource.hxx"
#include "ROOT/RDFHelpers.hxx"
#include "ROOT/RLazyDS.hxx"
#include "ROOT/RResultHandle.hxx"
#include "ROOT/RResultPtr.hxx"
#include "ROOT/RRootDS.hxx"
#include "ROOT/RSnapshotOptions.hxx"
#include "ROOT/RTrivialDS.hxx"
#include "ROOT/RTTreeDS.hxx"
#include "ROOT/RDF/ActionHelpers.hxx"
#include "ROOT/RDF/ColumnReaderUtils.hxx"
#include "ROOT/RDF/GraphNode.hxx"
#include "ROOT/RDF/GraphUtils.hxx"
#include "ROOT/RDF/HistoModels.hxx"
#include "ROOT/RDF/InterfaceUtils.hxx"
#include "ROOT/RDF/RActionBase.hxx"
#include "ROOT/RDF/RAction.hxx"
#include "ROOT/RDF/RActionImpl.hxx"
#include "ROOT/RDF/RColumnRegister.hxx"
#include "ROOT/RDF/RNewSampleNotifier.hxx"
#include "ROOT/RDF/RSampleInfo.hxx"
#include "ROOT/RDF/RDefineBase.hxx"
#include "ROOT/RDF/RDefaultValueFor.hxx"
#include "ROOT/RDF/RDefine.hxx"
#include "ROOT/RDF/RDefinePerSample.hxx"
#include "ROOT/RDF/RDefineReader.hxx"
#include "ROOT/RDF/RDSColumnReader.hxx"
#include "ROOT/RDF/RColumnReaderBase.hxx"
#include "ROOT/RDF/RCutFlowReport.hxx"
#include "ROOT/RDF/RDatasetSpec.hxx"
#include "ROOT/RDF/RDisplay.hxx"
#include "ROOT/RDF/RFilterBase.hxx"
#include "ROOT/RDF/RFilter.hxx"
#include "ROOT/RDF/RInterface.hxx"
#include "ROOT/RDF/RInterfaceBase.hxx"
#include "ROOT/RDF/RJittedAction.hxx"
#include "ROOT/RDF/RJittedDefine.hxx"
#include "ROOT/RDF/RJittedFilter.hxx"
#include "ROOT/RDF/RJittedVariation.hxx"
#include "ROOT/RDF/RLazyDSImpl.hxx"
#include "ROOT/RDF/RLoopManager.hxx"
#include "ROOT/RDF/RMergeableValue.hxx"
#include "ROOT/RDF/RMetaData.hxx"
#include "ROOT/RDF/RNodeBase.hxx"
#include "ROOT/RDF/RRangeBase.hxx"
#include "ROOT/RDF/RRange.hxx"
#include "ROOT/RDF/RResultMap.hxx"
#include "ROOT/RDF/RSample.hxx"
#include "ROOT/RDF/RFilterWithMissingValues.hxx"
#include "ROOT/RDF/RTreeColumnReader.hxx"
#include "ROOT/RDF/RVariation.hxx"
#include "ROOT/RDF/RVariationBase.hxx"
#include "ROOT/RDF/RVariationReader.hxx"
#include "ROOT/RDF/RVariationsDescription.hxx"
#include "ROOT/RDF/RVariedAction.hxx"
#include "ROOT/RDF/Utils.hxx"
#include "ROOT/RDF/PyROOTHelpers.hxx"
#include "ROOT/RDF/RDFDescription.hxx"
#include "ROOT/RNTupleDS.hxx"
#include "ROOT/RSqliteDS.hxx"
// ./tree/ntuple/G__ROOTNTuple.cxx
#include "ROOT/RCluster.hxx"
#include "ROOT/RClusterPool.hxx"
#include "ROOT/RColumn.hxx"
#include "ROOT/RColumnElementBase.hxx"
#include "ROOT/REntry.hxx"
#include "ROOT/RField.hxx"
#include "ROOT/RFieldBase.hxx"
#include "ROOT/RFieldToken.hxx"
#include "ROOT/RFieldUtils.hxx"
#include "ROOT/RFieldVisitor.hxx"
#include "ROOT/RMiniFile.hxx"
#include "ROOT/RNTuple.hxx"
#include "ROOT/RNTupleDescriptor.hxx"
#include "ROOT/RNTupleFillContext.hxx"
#include "ROOT/RNTupleFillStatus.hxx"
#include "ROOT/RNTupleImtTaskScheduler.hxx"
#include "ROOT/RNTupleJoinTable.hxx"
#include "ROOT/RNTupleMerger.hxx"
#include "ROOT/RNTupleMetrics.hxx"
#include "ROOT/RNTupleModel.hxx"
#include "ROOT/RNTupleParallelWriter.hxx"
#include "ROOT/RNTupleProcessor.hxx"
#include "ROOT/RNTupleRange.hxx"
#include "ROOT/RNTupleReadOptions.hxx"
#include "ROOT/RNTupleReader.hxx"
#include "ROOT/RNTupleSerialize.hxx"
#include "ROOT/RNTupleUtil.hxx"
#include "ROOT/RNTupleView.hxx"
#include "ROOT/RNTupleWriteOptions.hxx"
#include "ROOT/RNTupleWriteOptionsDaos.hxx"
#include "ROOT/RNTupleWriter.hxx"
#include "ROOT/RNTupleZip.hxx"
#include "ROOT/RPage.hxx"
#include "ROOT/RPageAllocator.hxx"
#include "ROOT/RPageNullSink.hxx"
#include "ROOT/RPagePool.hxx"
#include "ROOT/RPageSinkBuf.hxx"
#include "ROOT/RPageStorage.hxx"
#include "ROOT/RPageStorageFile.hxx"
#include "ROOT/RRawPtrWriteEntry.hxx"
// ./tree/ntupleutil/G__ROOTNTupleUtil.cxx
#include "ROOT/RNTupleImporter.hxx"
#include "ROOT/RNTupleExporter.hxx"
#include "ROOT/RNTupleInspector.hxx"
// ./io/io/G__RIO.cxx
#include "ROOT/RRawFile.hxx"
#include "ROOT/RRawFileTFile.hxx"
#include "ROOT/RRawFileUnix.hxx"
#include "ROOT/RIoUring.hxx"
#include "ROOT/TBufferMerger.hxx"
#include "TArchiveFile.h"
#include "TBufferFile.h"
#include "TBufferText.h"
#include "TBufferIO.h"
#include "TBufferJSON.h"
#include "TCollectionProxyFactory.h"
#include "TContainerConverters.h"
#include "TEmulatedMapProxy.h"
#include "TEmulatedCollectionProxy.h"
#include "TDirectoryFile.h"
#include "TFileCacheRead.h"
#include "TFileMerger.h"
#include "TFree.h"
#include "TFileCacheWrite.h"
#include "TFilePrefetch.h"
#include "TFile.h"
#include "TFPBlock.h"
#include "TGenCollectionStreamer.h"
#include "TGenCollectionProxy.h"
#include "TKey.h"
#include "TKeyMapFile.h"
#include "TLockFile.h"
#include "TMemFile.h"
#include "TMapFile.h"
#include "TMakeProject.h"
#include "TStreamerInfoActions.h"
#include "TVirtualCollectionIterators.h"
#include "TStreamerInfo.h"
#include "TZIPFile.h"
// ./net/net/G__Net.cxx
#include "NetErrors.h"
#include "RRemoteProtocol.h"
#include "TApplicationRemote.h"
#include "TApplicationServer.h"
#include "TFileStager.h"
#include "TFTP.h"
#include "TGrid.h"
#include "TGridCollection.h"
#include "TGridJDL.h"
#include "TGridJob.h"
#include "TGridJobStatus.h"
#include "TGridJobStatusList.h"
#include "TGridResult.h"
#include "TMessage.h"
#include "TMonitor.h"
#include "TNetFile.h"
#include "TNetFileStager.h"
#include "TParallelMergingFile.h"
#include "TPServerSocket.h"
#include "TPSocket.h"
#include "TSecContext.h"
#include "TServerSocket.h"
#include "TSocket.h"
#include "TSQLColumnInfo.h"
#include "TSQLMonitoring.h"
#include "TSQLResult.h"
#include "TSQLRow.h"
#include "TSQLServer.h"
#include "TSQLStatement.h"
#include "TSQLTableInfo.h"
#include "TUDPSocket.h"
#include "TWebFile.h"
#include "TSSLSocket.h"
#include "TS3HTTPRequest.h"
#include "TS3WebFile.h"
// ./net/netxng/G__NetxNG.cxx
#include "TNetXNGFile.h"
#include "TNetXNGFileStager.h"
#include "TNetXNGSystem.h"
#include "ROOT/RRawFileNetXNG.hxx"
// ./graf2d/gpadv7/G__ROOTGpadv7.cxx
#include "ROOT/RCanvas.hxx"
#include "ROOT/RFrame.hxx"
#include "ROOT/RMenuItems.hxx"
#include "ROOT/RColor.hxx"
#include "ROOT/RDisplayItem.hxx"
#include "ROOT/RAttrMap.hxx"
#include "ROOT/RAttrBase.hxx"
#include "ROOT/RAttrAggregation.hxx"
#include "ROOT/RAttrAxis.hxx"
#include "ROOT/RAttrBorder.hxx"
#include "ROOT/RAttrLine.hxx"
#include "ROOT/RAttrFill.hxx"
#include "ROOT/RAttrFont.hxx"
#include "ROOT/RAttrMarker.hxx"
#include "ROOT/RAttrMargins.hxx"
#include "ROOT/RAttrText.hxx"
#include "ROOT/RAttrValue.hxx"
#include "ROOT/RAxisDrawable.hxx"
#include "ROOT/RPalette.hxx"
#include "ROOT/RPaletteDrawable.hxx"
#include "ROOT/RDrawable.hxx"
#include "ROOT/ROnFrameDrawable.hxx"
#include "ROOT/RDrawableRequest.hxx"
#include "ROOT/RStyle.hxx"
#include "ROOT/RPadDisplayItem.hxx"
#include "ROOT/RPadExtent.hxx"
#include "ROOT/RPadBase.hxx"
#include "ROOT/RPad.hxx"
#include "ROOT/RPadLength.hxx"
#include "ROOT/RPadPos.hxx"
#include "ROOT/RPave.hxx"
#include "ROOT/RVirtualCanvasPainter.hxx"
#include "ROOT/TObjectDisplayItem.hxx"
#include "ROOT/TObjectDrawable.hxx"
// ./graf2d/primitivesv7/G__ROOTGraphicsPrimitives.cxx
#include "ROOT/RBox.hxx"
#include "ROOT/RFont.hxx"
#include "ROOT/RFrameTitle.hxx"
#include "ROOT/RLegend.hxx"
#include "ROOT/RLine.hxx"
#include "ROOT/RMarker.hxx"
#include "ROOT/RPaveText.hxx"
#include "ROOT/RText.hxx"
// ./graf2d/gpad/G__Gpad.cxx
#include "TAnnotation.h"
#include "TAttCanvas.h"
#include "TButton.h"
#include "TCanvas.h"
#include "TClassTree.h"
#include "TColorWheel.h"
#include "TControlBarButton.h"
#include "TControlBar.h"
#include "TCreatePrimitives.h"
#include "TDialogCanvas.h"
#include "TGroupButton.h"
#include "TInspectCanvas.h"
#include "TPad.h"
#include "TPadPainter.h"
#include "TPaveClass.h"
#include "TRatioPlot.h"
#include "TSliderBox.h"
#include "TSlider.h"
#include "TViewer3DPad.h"
#include "TView.h"
// ./graf2d/graf/G__Graf.cxx
#include "TArc.h"
#include "TArrow.h"
#include "TAttImage.h"
#include "TBox.h"
#include "TCandle.h"
#include "TCrown.h"
#include "TCurlyArc.h"
#include "TCurlyLine.h"
#include "TCutG.h"
#include "TDiamond.h"
#include "TEllipse.h"
#include "TFrame.h"
#include "TGaxis.h"
#include "TGraphPolar.h"
#include "TGraphPolargram.h"
#include "TGraphQQ.h"
#include "TImage.h"
#include "TImagePlugin.h"
#include "TLatex.h"
#include "TLegend.h"
#include "TLegendEntry.h"
#include "TLine.h"
#include "TLink.h"
#include "TMarker.h"
#include "TMathText.h"
#include "TPave.h"
#include "TPaveLabel.h"
#include "TPaveStats.h"
#include "TPaveText.h"
#include "TPavesText.h"
#include "TPie.h"
#include "TPieSlice.h"
#include "TPoints.h"
#include "TPolyLine.h"
#include "TTF.h"
#include "TText.h"
#include "TWbox.h"
// ./graf2d/postscript/G__Postscript.cxx
#include "TImageDump.h"
#include "TPDF.h"
#include "TPostScript.h"
#include "TSVG.h"
#include "TTeXDump.h"
// ./graf2d/x11/G__GX11.cxx
#include "TGX11.h"
// ./graf2d/x11ttf/G__GX11TTF.cxx
#include "TGX11TTF.h"
// ./graf2d/asimage/G__ASImage.cxx
#include "TASImage.h"
#include "TASImagePlugin.h"
#include "TASPluginGS.h"
#include "TASPngWriter.h"
// ./graf2d/asimage/G__ASImageGui.cxx
#include "TASPaletteEditor.h"
// ./graf2d/gviz/G__Gviz.cxx
#include "TGraphEdge.h"
#include "TGraphNode.h"
#include "TGraphStruct.h"
// ./graf2d/fitsio/G__FITSIO.cxx
#include "TFITS.h"
// ./graf3d/g3d/G__Graf3d.cxx
#include "TAxis3D.h"
#include "TBRIK.h"
#include "TCONE.h"
#include "TCONS.h"
#include "TCTUB.h"
#include "TELTU.h"
#include "TGeometry.h"
#include "TGTRA.h"
#include "THelix.h"
#include "THYPE.h"
#include "TMarker3DBox.h"
#include "TMaterial.h"
#include "TMixture.h"
#include "TNodeDiv.h"
#include "TNode.h"
#include "TPARA.h"
#include "TPCON.h"
#include "TPGON.h"
#include "TPoints3DABC.h"
#include "TPointSet3D.h"
#include "TPolyLine3D.h"
#include "TPolyMarker3D.h"
#include "TRotMatrix.h"
#include "TShape.h"
#include "TSPHE.h"
#include "TTRAP.h"
#include "TTRD1.h"
#include "TTRD2.h"
#include "TTUBE.h"
#include "TTUBS.h"
#include "TView3D.h"
#include "TXTRU.h"
#include "X3DBuffer.h"
// ./graf3d/gl/G__RGL.cxx
#include "TArcBall.h"
#include "TF2GL.h"
#include "TGL5DDataSetEditor.h"
#include "TGL5D.h"
#include "TGLAdapter.h"
#include "TGLAnnotation.h"
#include "TGLAutoRotator.h"
#include "TGLAxis.h"
#include "TGLAxisPainter.h"
#include "TGLBoundingBox.h"
#include "TGLBoxPainter.h"
#include "TGLCameraGuide.h"
#include "TGLCamera.h"
#include "TGLCameraOverlay.h"
#include "TGLClip.h"
#include "TGLClipSetEditor.h"
#include "TGLContext.h"
#include "TGLCylinder.h"
#include "TGLEmbeddedViewer.h"
#include "TGLEventHandler.h"
#include "TGLFaceSet.h"
#include "TGLFBO.h"
#include "TGLFontManager.h"
#include "TGLFormat.h"
#include "TGLH2PolyPainter.h"
#include "TGLHistPainter.h"
#include "TGLLegoPainter.h"
#include "TGLLightSetEditor.h"
#include "TGLLightSet.h"
#include "TGLLockable.h"
#include "TGLLogicalShape.h"
#include "TGLManip.h"
#include "TGLManipSet.h"
#include "TGLObject.h"
#include "TGLOrthoCamera.h"
#include "TGLOutput.h"
#include "TGLOverlayButton.h"
#include "TGLOverlay.h"
#include "TGLPadPainter.h"
#include "TGLPadUtils.h"
#include "TGLParametricEquationGL.h"
#include "TGLParametric.h"
#include "TGLPerspectiveCamera.h"
#include "TGLPhysicalShape.h"
#include "TGLPlot3D.h"
#include "TGLPlotBox.h"
#include "TGLPlotCamera.h"
#include "TGLPlotPainter.h"
#include "TGLPolyLine.h"
#include "TGLPolyMarker.h"
#include "TGLPShapeObjEditor.h"
#include "TGLPShapeObj.h"
#include "TGLPShapeRef.h"
#include "TGLQuadric.h"
#include "TGLRnrCtx.h"
#include "TGLRotateManip.h"
#include "TGLSAFrame.h"
#include "TGLSAViewer.h"
#include "TGLScaleManip.h"
#include "TGLSceneBase.h"
#include "TGLScene.h"
#include "TGLSceneInfo.h"
#include "TGLScenePad.h"
#include "TGLSelectBuffer.h"
#include "TGLSelectRecord.h"
#include "TGLSphere.h"
#include "TGLStopwatch.h"
#include "TGLSurfacePainter.h"
#include "TGLText.h"
#include "TGLTF3Painter.h"
#include "TGLTH3Composition.h"
#include "TGLTransManip.h"
#include "TGLUtil.h"
#include "TGLViewerBase.h"
#include "TGLViewerEditor.h"
#include "TGLViewer.h"
#include "TGLVoxelPainter.h"
#include "TGLWidget.h"
#include "TH2GL.h"
#include "TH3GL.h"
#include "TPointSet3DGL.h"
#include "TGLSdfFontMaker.h"
#include "TX11GL.h"
// ./gui/gui/G__Gui.cxx
#include "HelpText.h"
#include "TG3DLine.h"
#include "TGApplication.h"
#include "TGButton.h"
#include "TGButtonGroup.h"
#include "TGCanvas.h"
#include "TGClient.h"
#include "TGColorDialog.h"
#include "TGColorSelect.h"
#include "TGComboBox.h"
#include "TGCommandPlugin.h"
#include "TGDNDManager.h"
#include "TGDimension.h"
#include "TGDockableFrame.h"
#include "TGDoubleSlider.h"
#include "TGEventHandler.h"
#include "TGFSComboBox.h"
#include "TGFSContainer.h"
#include "TGFileBrowser.h"
#include "TGFileDialog.h"
#include "TGFont.h"
#include "TGFontDialog.h"
#include "TGFrame.h"
#include "TGGC.h"
#include "TGIcon.h"
#include "TGIdleHandler.h"
#include "TGImageMap.h"
#include "TGInputDialog.h"
#include "TGLabel.h"
#include "TGLayout.h"
#include "TGListBox.h"
#include "TGListTree.h"
#include "TGListView.h"
#include "TGMdi.h"
#include "TGMdiDecorFrame.h"
#include "TGMdiFrame.h"
#include "TGMdiMainFrame.h"
#include "TGMdiMenu.h"
#include "TGMenu.h"
#include "TGMimeTypes.h"
#include "TGMsgBox.h"
#include "TGNumberEntry.h"
#include "TGObject.h"
#include "TGPack.h"
#include "TGPasswdDialog.h"
#include "TGPicture.h"
#include "TGProgressBar.h"
#include "TGRedirectOutputGuard.h"
#include "TGResourcePool.h"
#include "TGScrollBar.h"
#include "TGShapedFrame.h"
#include "TGShutter.h"
#include "TGSimpleTable.h"
#include "TGSimpleTableInterface.h"
#include "TGSlider.h"
#include "TGSpeedo.h"
#include "TGSplitFrame.h"
#include "TGSplitter.h"
#include "TGStatusBar.h"
#include "TGString.h"
#include "TGTab.h"
#include "TGTable.h"
#include "TGTableCell.h"
#include "TGTableContainer.h"
#include "TGTableHeader.h"
#include "TGTableLayout.h"
#include "TGText.h"
#include "TGTextBuffer.h"
#include "TGTextEdit.h"
#include "TGTextEditDialogs.h"
#include "TGTextEditor.h"
#include "TGTextEntry.h"
#include "TGTextView.h"
#include "TGTextViewStream.h"
#include "TGToolBar.h"
#include "TGToolTip.h"
#include "TGTripleSlider.h"
#include "TGView.h"
#include "TGWidget.h"
#include "TGWindow.h"
#include "TGXYLayout.h"
#include "TGuiBuilder.h"
#include "TRootApplication.h"
#include "TRootBrowser.h"
#include "TRootBrowserLite.h"
#include "TRootCanvas.h"
#include "TRootContextMenu.h"
#include "TRootControlBar.h"
#include "TRootDialog.h"
#include "TRootEmbeddedCanvas.h"
#include "TRootGuiFactory.h"
#include "TRootHelpDialog.h"
#include "TVirtualDragManager.h"
#include "WidgetMessageTypes.h"
// ./gui/fitpanel/G__FitPanel.cxx
#include "TAdvancedGraphicsDialog.h"
#include "TFitEditor.h"
#include "TFitParametersDialog.h"
#include "TTreeInput.h"
// ./gui/fitpanelv7/G__ROOTFitPanelv7.cxx
#include "ROOT/RFitPanel.hxx"
#include "ROOT/RFitPanelModel.hxx"
// ./bindings/tpython/G__ROOTTPython.cxx
#include "TPyArg.h"
#include "TPyReturn.h"
#include "TPython.h"
// ./tmva/tmva/G__TMVA.cxx
#include "TMVA/BDTEventWrapper.h"
#include "TMVA/BinarySearchTree.h"
#include "TMVA/BinarySearchTreeNode.h"
#include "TMVA/BinaryTree.h"
#include "TMVA/CCPruner.h"
#include "TMVA/CCTreeWrapper.h"
#include "TMVA/Classification.h"
#include "TMVA/ClassifierFactory.h"
#include "TMVA/ClassInfo.h"
#include "TMVA/Config.h"
#include "TMVA/Configurable.h"
#include "TMVA/ConvergenceTest.h"
#include "TMVA/CostComplexityPruneTool.h"
#include "TMVA/CrossEntropy.h"
#include "TMVA/CrossValidation.h"
#include "TMVA/CvSplit.h"
#include "TMVA/DataInputHandler.h"
#include "TMVA/DataLoader.h"
#include "TMVA/DataSetFactory.h"
#include "TMVA/DataSet.h"
#include "TMVA/DataSetInfo.h"
#include "TMVA/DataSetManager.h"
#include "TMVA/DecisionTree.h"
#include "TMVA/DecisionTreeNode.h"
#include "TMVA/Envelope.h"
#include "TMVA/Event.h"
#include "TMVA/ExpectedErrorPruneTool.h"
#include "TMVA/Executor.h"
#include "TMVA/Factory.h"
#include "TMVA/FitterBase.h"
#include "TMVA/GeneticAlgorithm.h"
#include "TMVA/GeneticFitter.h"
#include "TMVA/GeneticGenes.h"
#include "TMVA/GeneticPopulation.h"
#include "TMVA/GeneticRange.h"
#include "TMVA/GiniIndex.h"
#include "TMVA/GiniIndexWithLaplace.h"
#include "TMVA/HyperParameterOptimisation.h"
#include "TMVA/IFitterTarget.h"
#include "TMVA/IMethod.h"
#include "TMVA/Interval.h"
#include "TMVA/IPruneTool.h"
#include "TMVA/KDEKernel.h"
#include "TMVA/LDA.h"
#include "TMVA/LogInterval.h"
#include "TMVA/LossFunction.h"
#include "TMVA/MCFitter.h"
#include "TMVA/MethodANNBase.h"
#include "TMVA/MethodBase.h"
#include "TMVA/MethodBayesClassifier.h"
#include "TMVA/MethodBDT.h"
#include "TMVA/MethodBoost.h"
#include "TMVA/MethodCategory.h"
#include "TMVA/MethodCFMlpANN_def.h"
#include "TMVA/MethodCFMlpANN.h"
#include "TMVA/MethodCFMlpANN_Utils.h"
#include "TMVA/MethodCompositeBase.h"
#include "TMVA/MethodCrossValidation.h"
#include "TMVA/MethodCuts.h"
#include "TMVA/MethodDL.h"
#include "TMVA/MethodDNN.h"
#include "TMVA/MethodDT.h"
#include "TMVA/MethodFDA.h"
#include "TMVA/MethodFisher.h"
#include "TMVA/MethodHMatrix.h"
#include "TMVA/MethodKNN.h"
#include "TMVA/MethodLD.h"
#include "TMVA/MethodLikelihood.h"
#include "TMVA/MethodMLP.h"
#include "TMVA/MethodPDEFoam.h"
#include "TMVA/MethodPDERS.h"
#include "TMVA/MethodRuleFit.h"
#include "TMVA/MethodSVM.h"
#include "TMVA/MethodTMlpANN.h"
#include "TMVA/MinuitFitter.h"
#include "TMVA/MinuitWrapper.h"
#include "TMVA/MisClassificationError.h"
#include "TMVA/ModulekNN.h"
#include "TMVA/Monitoring.h"
#include "TMVA/MsgLogger.h"
#include "TMVA/NeuralNet.h"
#include "TMVA/Node.h"
#include "TMVA/NodekNN.h"
#include "TMVA/OptimizeConfigParameters.h"
#include "TMVA/Option.h"
#include "TMVA/OptionMap.h"
#include "TMVA/Pattern.h"
#include "TMVA/PDEFoamCell.h"
#include "TMVA/PDEFoamDecisionTreeDensity.h"
#include "TMVA/PDEFoamDecisionTree.h"
#include "TMVA/PDEFoamDensityBase.h"
#include "TMVA/PDEFoamDiscriminantDensity.h"
#include "TMVA/PDEFoamDiscriminant.h"
#include "TMVA/PDEFoamEventDensity.h"
#include "TMVA/PDEFoamEvent.h"
#include "TMVA/PDEFoam.h"
#include "TMVA/PDEFoamKernelBase.h"
#include "TMVA/PDEFoamKernelGauss.h"
#include "TMVA/PDEFoamKernelLinN.h"
#include "TMVA/PDEFoamKernelTrivial.h"
#include "TMVA/PDEFoamMultiTarget.h"
#include "TMVA/PDEFoamTargetDensity.h"
#include "TMVA/PDEFoamTarget.h"
#include "TMVA/PDEFoamVect.h"
#include "TMVA/PDF.h"
#include "TMVA/QuickMVAProbEstimator.h"
#include "TMVA/Ranking.h"
#include "TMVA/Reader.h"
#include "TMVA/RegressionVariance.h"
#include "TMVA/ResultsClassification.h"
#include "TMVA/Results.h"
#include "TMVA/ResultsMulticlass.h"
#include "TMVA/ResultsRegression.h"
#include "TMVA/ROCCalc.h"
#include "TMVA/ROCCurve.h"
#include "TMVA/RootFinder.h"
#include "TMVA/RuleCut.h"
#include "TMVA/RuleEnsemble.h"
#include "TMVA/RuleFitAPI.h"
#include "TMVA/RuleFit.h"
#include "TMVA/RuleFitParams.h"
#include "TMVA/Rule.h"
#include "TMVA/SdivSqrtSplusB.h"
#include "TMVA/SeparationBase.h"
#include "TMVA/SimulatedAnnealingFitter.h"
#include "TMVA/SimulatedAnnealing.h"
#include "TMVA/SVEvent.h"
#include "TMVA/SVKernelFunction.h"
#include "TMVA/SVKernelMatrix.h"
#include "TMVA/SVWorkingSet.h"
#include "TMVA/TActivationChooser.h"
#include "TMVA/TActivation.h"
#include "TMVA/TActivationIdentity.h"
#include "TMVA/TActivationRadial.h"
#include "TMVA/TActivationReLU.h"
#include "TMVA/TActivationSigmoid.h"
#include "TMVA/TActivationTanh.h"
#include "TMVA/Timer.h"
#include "TMVA/TNeuron.h"
#include "TMVA/TNeuronInputAbs.h"
#include "TMVA/TNeuronInputChooser.h"
#include "TMVA/TNeuronInput.h"
#include "TMVA/TNeuronInputSqSum.h"
#include "TMVA/TNeuronInputSum.h"
#include "TMVA/Tools.h"
#include "TMVA/TrainingHistory.h"
#include "TMVA/TransformationHandler.h"
#include "TMVA/TSpline1.h"
#include "TMVA/TSpline2.h"
#include "TMVA/TSynapse.h"
#include "TMVA/Types.h"
#include "TMVA/VariableDecorrTransform.h"
#include "TMVA/VariableGaussTransform.h"
#include "TMVA/VariableIdentityTransform.h"
#include "TMVA/VariableImportance.h"
#include "TMVA/VariableInfo.h"
#include "TMVA/VariableNormalizeTransform.h"
#include "TMVA/VariablePCATransform.h"
#include "TMVA/VariableRearrangeTransform.h"
#include "TMVA/VariableTransformBase.h"
#include "TMVA/VariableTransform.h"
#include "TMVA/VarTransformHandler.h"
#include "TMVA/Version.h"
#include "TMVA/Volume.h"
// ./tmva/tmva/G__TMVAUtils.cxx
#include "TMVA/RTensorUtils.hxx"
#include "TMVA/RStandardScaler.hxx"
#include "TMVA/RReader.hxx"
#include "TMVA/RInferenceUtils.hxx"
#include "TMVA/RBDT.hxx"
#include "TMVA/RSofieReader.hxx"
#include "TMVA/BatchGenerator/RBatchGenerator.hxx"
#include "TMVA/BatchGenerator/RBatchLoader.hxx"
#include "TMVA/BatchGenerator/RChunkLoader.hxx"
// ./tmva/tmvagui/G__TMVAGui.cxx
#include "TMVA/BDT.h"
#include "TMVA/BDTControlPlots.h"
#include "TMVA/BDT_Reg.h"
#include "TMVA/BoostControlPlots.h"
#include "TMVA/CorrGui.h"
#include "TMVA/CorrGuiMultiClass.h"
#include "TMVA/MovieMaker.h"
#include "TMVA/PlotFoams.h"
#include "TMVA/TMVAGui.h"
#include "TMVA/TMVAMultiClassGui.h"
#include "TMVA/TMVARegGui.h"
#include "TMVA/annconvergencetest.h"
#include "TMVA/compareanapp.h"
#include "TMVA/correlations.h"
#include "TMVA/correlationsMultiClass.h"
#include "TMVA/correlationscatters.h"
#include "TMVA/correlationscattersMultiClass.h"
#include "TMVA/deviations.h"
#include "TMVA/efficiencies.h"
#include "TMVA/efficienciesMulticlass.h"
#include "TMVA/likelihoodrefs.h"
#include "TMVA/mvaeffs.h"
#include "TMVA/mvas.h"
#include "TMVA/mvasMulticlass.h"
#include "TMVA/mvaweights.h"
#include "TMVA/network.h"
#include "TMVA/paracoor.h"
#include "TMVA/probas.h"
#include "TMVA/regression_averagedevs.h"
#include "TMVA/rulevis.h"
#include "TMVA/rulevisCorr.h"
#include "TMVA/rulevisHists.h"
#include "TMVA/tmvaglob.h"
#include "TMVA/training_history.h"
#include "TMVA/variables.h"
#include "TMVA/variablesMultiClass.h"
// ./tmva/pymva/G__PyMVA.cxx
#include "TMVA/MethodPyAdaBoost.h"
#include "TMVA/MethodPyGTB.h"
#include "TMVA/MethodPyKeras.h"
#include "TMVA/MethodPyRandomForest.h"
#include "TMVA/MethodPyTorch.h"
#include "TMVA/RModelParser_Keras.h"
#include "TMVA/RModelParser_PyTorch.h"
#include "TMVA/PyMethodBase.h"
// ./tmva/sofie/G__ROOTTMVASofie.cxx
#include "TMVA/OperatorList.hxx"
#include "TMVA/RModel_Base.hxx"
#include "TMVA/RModel.hxx"
#include "TMVA/ROperator.hxx"
#include "TMVA/ROperator_BasicUnary.hxx"
#include "TMVA/ROperator_BasicBinary.hxx"
#include "TMVA/ROperator_BasicNary.hxx"
#include "TMVA/ROperator_BatchNormalization.hxx"
#include "TMVA/ROperator_Conv.hxx"
#include "TMVA/ROperator_ConvTranspose.hxx"
#include "TMVA/ROperator_Gemm.hxx"
#include "TMVA/ROperator_Relu.hxx"
#include "TMVA/ROperator_Tanh.hxx"
#include "TMVA/ROperator_LeakyRelu.hxx"
#include "TMVA/ROperator_Reshape.hxx"
#include "TMVA/ROperator_Selu.hxx"
#include "TMVA/ROperator_Sigmoid.hxx"
#include "TMVA/ROperator_Slice.hxx"
#include "TMVA/ROperator_Transpose.hxx"
#include "TMVA/ROperator_Pool.hxx"
#include "TMVA/ROperator_Concat.hxx"
#include "TMVA/ROperator_Identity.hxx"
#include "TMVA/ROperator_Constant.hxx"
#include "TMVA/ROperator_Softmax.hxx"
#include "TMVA/ROperator_Reduce.hxx"
#include "TMVA/ROperator_Shape.hxx"
#include "TMVA/ROperator_Cast.hxx"
#include "TMVA/ROperator_Custom.hxx"
#include "TMVA/ROperator_LayerNormalization.hxx"
#include "TMVA/ROperator_Expand.hxx"
#include "TMVA/ROperator_Erf.hxx"
#include "TMVA/ROperator_Swish.hxx"
#include "TMVA/ROperator_Elu.hxx"
#include "TMVA/ROperator_Comparision.hxx"
#include "TMVA/ROperator_EyeLike.hxx"
#include "TMVA/ROperator_Range.hxx"
#include "TMVA/ROperator_TopK.hxx"
#include "TMVA/ROperator_Tile.hxx"
#include "TMVA/ROperator_Split.hxx"
#include "TMVA/ROperator_SubGraph.hxx"
#include "TMVA/ROperator_Pad.hxx"
#include "TMVA/ROperator_Where.hxx"
#include "TMVA/ROperator_Einsum.hxx"
#include "TMVA/ROperator_Random.hxx"
#include "TMVA/ROperator_ScatterElements.hxx"
#include "TMVA/SOFIE_common.hxx"
#include "TMVA/SOFIEHelpers.hxx"
#include "TMVA/FunctionList.hxx"
#include "TMVA/RModel_GNN.hxx"
#include "TMVA/RModel_GraphIndependent.hxx"
#include "TMVA/RFunction.hxx"
#include "TMVA/RFunction_MLP.hxx"
#include "TMVA/RFunction_Sum.hxx"
#include "TMVA/RFunction_Mean.hxx"
// ./roofit/codegen/G__RooFitCodegen.cxx
#include "RooFit/CodegenImpl.h"
// ./roofit/roofitcore/G__RooFitCore.cxx
#include "Roo1DTable.h"
#include "RooAICRegistry.h"
#include "RooAbsAnaConvPdf.h"
#include "RooAbsArg.h"
#include "RooAbsBinning.h"
#include "RooAbsCache.h"
#include "RooAbsCacheElement.h"
#include "RooAbsCachedPdf.h"
#include "RooAbsCachedReal.h"
#include "RooAbsCategory.h"
#include "RooAbsCategoryLValue.h"
#include "RooAbsCollection.h"
#include "RooAbsData.h"
#include "RooAbsDataHelper.h"
#include "RooAbsDataStore.h"
#include "RooAbsFunc.h"
#include "RooAbsGenContext.h"
#include "RooAbsHiddenReal.h"
#include "RooAbsIntegrator.h"
#include "RooAbsLValue.h"
#include "RooAbsMCStudyModule.h"
#include "RooAbsMoment.h"
#include "RooAbsPdf.h"
#include "RooAbsProxy.h"
#include "RooAbsReal.h"
#include "RooAbsRealLValue.h"
#include "RooAbsSelfCachedPdf.h"
#include "RooAbsSelfCachedReal.h"
#include "RooAbsStudy.h"
#include "RooAddGenContext.h"
#include "RooAddModel.h"
#include "RooAddPdf.h"
#include "RooAddition.h"
#include "RooArgList.h"
#include "RooArgProxy.h"
#include "RooArgSet.h"
#include "RooBinSamplingPdf.h"
#include "RooBinWidthFunction.h"
#include "RooBinnedGenContext.h"
#include "RooBinning.h"
#include "RooBinningCategory.h"
#include "RooBrentRootFinder.h"
#include "RooCacheManager.h"
#include "RooCachedPdf.h"
#include "RooCachedReal.h"
#include "RooCategory.h"
#include "RooCategoryProxy.h"
#include "RooChangeTracker.h"
#include "RooClassFactory.h"
#include "RooCmdArg.h"
#include "RooCmdConfig.h"
#include "RooCollectionProxy.h"
#include "RooCompositeDataStore.h"
#include "RooConstVar.h"
#include "RooConstraintSum.h"
#include "RooConvCoefVar.h"
#include "RooConvGenContext.h"
#include "RooCurve.h"
#include "RooCustomizer.h"
#include "RooDLLSignificanceMCSModule.h"
#include "RooDataHist.h"
#include "RooDataHistSliceIter.h"
#include "RooDataProjBinding.h"
#include "RooDataSet.h"
#include "RooDerivative.h"
#include "RooDirItem.h"
#include "RooDouble.h"
#include "RooEffGenContext.h"
#include "RooEffProd.h"
#include "RooEfficiency.h"
#include "RooEllipse.h"
#include "RooErrorHandler.h"
#include "RooErrorVar.h"
#include "RooExpensiveObjectCache.h"
#include "RooExtendPdf.h"
#include "RooExtendedBinding.h"
#include "RooExtendedTerm.h"
#include "RooFFTConvPdf.h"
#include "RooFactoryWSTool.h"
#include "RooFirstMoment.h"
#include "RooFit.h"
#include "RooFit/CodegenContext.h"
#include "RooFit/Config.h"
#include "RooFit/Detail/MathFuncs.h"
#include "RooFit/Detail/NormalizationHelpers.h"
#include "RooFit/Detail/RooNLLVarNew.h"
#include "RooFit/Detail/RooNormalizedPdf.h"
#include "RooFit/EvalContext.h"
#include "RooFit/Evaluator.h"
#include "RooFit/Floats.h"
#include "RooFit/ModelConfig.h"
#include "RooFit/TestStatistics/LikelihoodGradientWrapper.h"
#include "RooFit/TestStatistics/LikelihoodWrapper.h"
#include "RooFit/TestStatistics/RooAbsL.h"
#include "RooFit/TestStatistics/RooBinnedL.h"
#include "RooFit/TestStatistics/RooRealL.h"
#include "RooFit/TestStatistics/RooSubsidiaryL.h"
#include "RooFit/TestStatistics/RooSumL.h"
#include "RooFit/TestStatistics/RooUnbinnedL.h"
#include "RooFit/TestStatistics/SharedOffset.h"
#include "RooFit/TestStatistics/buildLikelihood.h"
#include "RooFitLegacy/RooCatTypeLegacy.h"
#include "RooFitLegacy/RooCategorySharedProperties.h"
#include "RooFitLegacy/RooTreeData.h"
#include "RooFitResult.h"
#include "RooFormulaVar.h"
#include "RooFracRemainder.h"
#include "RooFuncWrapper.h"
#include "RooFunctor.h"
#include "RooGenContext.h"
#include "RooGenFitStudy.h"
#include "RooGenericPdf.h"
#include "RooGlobalFunc.h"
#include "RooHelpers.h"
#include "RooHist.h"
#include "RooHistError.h"
#include "RooHistFunc.h"
#include "RooHistPdf.h"
#include "RooInvTransform.h"
#include "RooLinTransBinning.h"
#include "RooLinearCombination.h"
#include "RooLinearVar.h"
#include "RooLinkedList.h"
#include "RooLinkedListElem.h"
#include "RooLinkedListIter.h"
#include "RooListProxy.h"
#include "RooMCStudy.h"
#include "RooMappedCategory.h"
#include "RooMath.h"
#include "RooMinimizer.h"
#include "RooMoment.h"
#include "RooMsgService.h"
#include "RooMultiCategory.h"
#include "RooMultiVarGaussian.h"
#include "RooNameReg.h"
#include "RooNormSetCache.h"
#include "RooNumCdf.h"
#include "RooNumConvPdf.h"
#include "RooNumConvolution.h"
#include "RooNumGenConfig.h"
#include "RooNumIntConfig.h"
#include "RooNumIntFactory.h"
#include "RooNumRunningInt.h"
#include "RooNumber.h"
#include "RooObjCacheManager.h"
#include "RooParamBinning.h"
#include "RooPlot.h"
#include "RooPlotable.h"
#include "RooPolyFunc.h"
#include "RooPolyVar.h"
#include "RooPrintable.h"
#include "RooProdGenContext.h"
#include "RooProdPdf.h"
#include "RooProduct.h"
#include "RooProfileLL.h"
#include "RooProjectedPdf.h"
#include "RooPullVar.h"
#include "RooQuasiRandomGenerator.h"
#include "RooRandom.h"
#include "RooRandomizeParamMCSModule.h"
#include "RooRangeBinning.h"
#include "RooRangeBoolean.h"
#include "RooRatio.h"
#include "RooRealBinding.h"
#include "RooRealConstant.h"
#include "RooRealIntegral.h"
#include "RooRealProxy.h"
#include "RooRealSumFunc.h"
#include "RooRealSumPdf.h"
#include "RooRealVar.h"
#include "RooRealVarSharedProperties.h"
#include "RooRecursiveFraction.h"
#include "RooRefCountList.h"
#include "RooResolutionModel.h"
#include "RooSTLRefCountList.h"
#include "RooSecondMoment.h"
#include "RooSetProxy.h"
#include "RooSharedProperties.h"
#include "RooSimGenContext.h"
#include "RooSimSplitGenContext.h"
#include "RooSimWSTool.h"
#include "RooSimultaneous.h"
#include "RooStreamParser.h"
#include "RooStringVar.h"
#include "RooStringView.h"
#include "RooStudyManager.h"
#include "RooStudyPackage.h"
#include "RooSuperCategory.h"
#include "RooTObjWrap.h"
#include "RooTable.h"
#include "RooTemplateProxy.h"
#include "RooThresholdCategory.h"
#include "RooTrace.h"
#include "RooTreeDataStore.h"
#include "RooTruthModel.h"
#include "RooUniformBinning.h"
#include "RooVectorDataStore.h"
#include "RooWorkspace.h"
#include "RooWorkspaceHandle.h"
#include "RooWrapperPdf.h"
// ./roofit/roofit/G__RooFit.cxx
#include "Roo2DKeysPdf.h"
#include "RooArgusBG.h"
#include "RooBCPEffDecay.h"
#include "RooBCPGenDecay.h"
#include "RooBDecay.h"
#include "RooBernstein.h"
#include "RooBifurGauss.h"
#include "RooBlindTools.h"
#include "RooBMixDecay.h"
#include "RooBreitWigner.h"
#include "RooBukinPdf.h"
#include "RooCBShape.h"
#include "RooCrystalBall.h"
#include "RooCFunction1Binding.h"
#include "RooCFunction2Binding.h"
#include "RooCFunction3Binding.h"
#include "RooCFunction4Binding.h"
#include "RooChebychev.h"
#include "RooChi2MCSModule.h"
#include "RooChiSquarePdf.h"
#include "RooDecay.h"
#include "RooDstD0BG.h"
#include "RooExponential.h"
#include "RooLegacyExpPoly.h"
#include "RooPowerSum.h"
#include "RooFunctor1DBinding.h"
#include "RooFunctorBinding.h"
#include "RooGamma.h"
#include "RooGaussian.h"
#include "RooGaussModel.h"
#include "RooGExpModel.h"
#include "RooHistConstraint.h"
#include "RooIntegralMorph.h"
#include "RooJeffreysPrior.h"
#include "RooKeysPdf.h"
#include "RooLagrangianMorphFunc.h"
#include "RooLandau.h"
#include "RooLognormal.h"
#include "RooMathCoreReg.h"
#include "RooMomentMorphFunc.h"
#include "RooMomentMorphFuncND.h"
#include "RooMomentMorph.h"
#include "RooMultiBinomial.h"
#include "RooNDKeysPdf.h"
#include "RooNonCPEigenDecay.h"
#include "RooNovosibirsk.h"
#include "RooParametricStepFunction.h"
#include "RooParamHistFunc.h"
#include "RooPoisson.h"
#include "RooPolynomial.h"
#include "RooPyBind.h"
#include "RooSpline.h"
#include "RooStepFunction.h"
#include "RooTFnBinding.h"
#include "RooTFnPdfBinding.h"
#include "RooTMathReg.h"
#include "RooUnblindCPAsymVar.h"
#include "RooUnblindOffset.h"
#include "RooUnblindPrecision.h"
#include "RooUnblindUniform.h"
#include "RooUniform.h"
#include "RooVoigtian.h"
#include "RooJohnson.h"
// ./roofit/roofitmore/G__RooFitMore.cxx
#include "RooFitMoreLib.h"
#include "RooLegendre.h"
#include "RooMathMoreReg.h"
#include "RooSpHarmonic.h"
#include "RooNonCentralChiSquare.h"
#include "RooHypatia2.h"
// ./roofit/roostats/G__RooStats.cxx
#include "RooStats/AsymptoticCalculator.h"
#include "RooStats/BayesianCalculator.h"
#include "RooStats/BernsteinCorrection.h"
#include "RooStats/CombinedCalculator.h"
#include "RooStats/ConfidenceBelt.h"
#include "RooStats/ConfInterval.h"
#include "RooStats/DebuggingSampler.h"
#include "RooStats/DebuggingTestStat.h"
#include "RooStats/DetailedOutputAggregator.h"
#include "RooStats/FeldmanCousins.h"
#include "RooStats/FrequentistCalculator.h"
#include "RooStats/Heaviside.h"
#include "RooStats/HLFactory.h"
#include "RooStats/HybridCalculator.h"
#include "RooStats/HybridPlot.h"
#include "RooStats/HybridResult.h"
#include "RooStats/HypoTestCalculatorGeneric.h"
#include "RooStats/HypoTestCalculator.h"
#include "RooStats/HypoTestInverter.h"
#include "RooStats/HypoTestInverterPlot.h"
#include "RooStats/HypoTestInverterResult.h"
#include "RooStats/HypoTestPlot.h"
#include "RooStats/HypoTestResult.h"
#include "RooStats/IntervalCalculator.h"
#include "RooStats/LikelihoodInterval.h"
#include "RooStats/LikelihoodIntervalPlot.h"
#include "RooStats/MarkovChain.h"
#include "RooStats/MaxLikelihoodEstimateTestStat.h"
#include "RooStats/MCMCCalculator.h"
#include "RooStats/MCMCInterval.h"
#include "RooStats/MCMCIntervalPlot.h"
#include "RooStats/MetropolisHastings.h"
#include "RooStats/ModelConfig.h"
#include "RooStats/NeymanConstruction.h"
#include "RooStats/NumberCountingPdfFactory.h"
#include "RooStats/NumberCountingUtils.h"
#include "RooStats/NumEventsTestStat.h"
#include "RooStats/PdfProposal.h"
#include "RooStats/PointSetInterval.h"
#include "RooStats/ProfileInspector.h"
#include "RooStats/ProfileLikelihoodCalculator.h"
#include "RooStats/ProfileLikelihoodTestStat.h"
#include "RooStats/ProposalFunction.h"
#include "RooStats/ProposalHelper.h"
#include "RooStats/RatioOfProfiledLikelihoodsTestStat.h"
#include "RooStats/RooStatsUtils.h"
#include "RooStats/SamplingDistPlot.h"
#include "RooStats/SamplingDistribution.h"
#include "RooStats/SequentialProposal.h"
#include "RooStats/SimpleInterval.h"
#include "RooStats/SimpleLikelihoodRatioTestStat.h"
#include "RooStats/SPlot.h"
#include "RooStats/TestStatistic.h"
#include "RooStats/TestStatSampler.h"
#include "RooStats/ToyMCImportanceSampler.h"
#include "RooStats/ToyMCSampler.h"
#include "RooStats/UniformProposal.h"
#include "RooStats/UpperLimitMCSModule.h"
// ./roofit/histfactory/G__HistFactory.cxx
#include "RooStats/HistFactory/Asimov.h"
#include "RooStats/HistFactory/Channel.h"
#include "RooStats/HistFactory/Data.h"
#include "RooStats/HistFactory/Detail/HistFactoryImpl.h"
#include "RooStats/HistFactory/FlexibleInterpVar.h"
#include "RooStats/HistFactory/HistFactoryException.h"
#include "RooStats/HistFactory/HistFactoryModelUtils.h"
#include "RooStats/HistFactory/HistFactoryNavigation.h"
#include "RooStats/HistFactory/HistoToWorkspaceFactoryFast.h"
#include "RooStats/HistFactory/HistRef.h"
#include "RooStats/HistFactory/LinInterpVar.h"
#include "RooStats/HistFactory/MakeModelAndMeasurementsFast.h"
#include "RooStats/HistFactory/Measurement.h"
#include "RooStats/HistFactory/ParamHistFunc.h"
#include "RooStats/HistFactory/PiecewiseInterpolation.h"
#include "RooStats/HistFactory/PreprocessFunction.h"
#include "RooStats/HistFactory/RooBarlowBeestonLL.h"
#include "RooStats/HistFactory/Sample.h"
#include "RooStats/HistFactory/Systematics.h"
#include "RooStats/HistFactory/ConfigParser.h"
// ./roofit/jsoninterface/G__RooFitJSONInterface.cxx
#include "RooFit/Detail/JSONInterface.h"
// ./roofit/hs3/G__RooFitHS3.cxx
#include "RooFitHS3/JSONIO.h"
#include "RooFitHS3/RooJSONFactoryWSTool.h"
// ./roofit/xroofit/G__RooFitXRooFit.cxx
#include "RooBrowser.h"
#include "XRooFit.h"
#include "RooFit/xRooFit/xRooFit.h"
#include "RooFit/xRooFit/xRooNode.h"
#include "RooFit/xRooFit/xRooNLLVar.h"
#include "RooFit/xRooFit/xRooHypoSpace.h"
#include "RooFit/xRooFit/xRooBrowser.h"
// ./core/G__Core.cxx
#include "ROOT/RFloat16.hxx"
#include "ROOT/TErrorDefaultHandler.hxx"
#include "ROOT/TExecutorCRTP.hxx"
#include "ROOT/TSequentialExecutor.hxx"
#include "ROOT/StringConv.hxx"
#include "Buttons.h"
#include "Bytes.h"
#include "Byteswap.h"
#include "KeySymbols.h"
#include "MessageTypes.h"
#include "Riostream.h"
#include "Rtypes.h"
#include "TApplication.h"
#include "TAtt3D.h"
#include "TAttAxis.h"
#include "TAttBBox2D.h"
#include "TAttBBox.h"
#include "TAttFill.h"
#include "TAttLine.h"
#include "TAttMarker.h"
#include "TAttPad.h"
#include "TAttText.h"
#include "TBase64.h"
#include "TBenchmark.h"
#include "TBuffer3D.h"
#include "TBuffer3DTypes.h"
#include "TBuffer.h"
#include "TColor.h"
#include "TColorGradient.h"
#include "TDatime.h"
#include "TDirectory.h"
#include "TEnv.h"
#include "TException.h"
#include "TExec.h"
#include "TFileCollection.h"
#include "TFileInfo.h"
#include "TFolder.h"
#include "TInetAddress.h"
#include "TMacro.h"
#include "TMathBase.h"
#include "TMD5.h"
#include "TMemberInspector.h"
#include "TMessageHandler.h"
#include "TNamed.h"
#include "TNotifyLink.h"
#include "TObject.h"
#include "TObjString.h"
#include "TParameter.h"
#include "TPluginManager.h"
#include "TPoint.h"
#include "TPRegexp.h"
#include "TProcessID.h"
#include "TProcessUUID.h"
#include "TQClass.h"
#include "TQCommand.h"
#include "TQConnection.h"
#include "TQObject.h"
#include "TRedirectOutputGuard.h"
#include "TRefCnt.h"
#include "TRef.h"
#include "TRegexp.h"
#include "TRemoteObject.h"
#include "TROOT.h"
#include "TRootIOCtor.h"
#include "TStopwatch.h"
#include "TStorage.h"
#include "TString.h"
#include "TStringLong.h"
#include "TStyle.h"
#include "TSysEvtHandler.h"
#include "TSystemDirectory.h"
#include "TSystemFile.h"
#include "TSystem.h"
#include "TTask.h"
#include "TThreadSlots.h"
#include "TTime.h"
#include "TTimer.h"
#include "TTimeStamp.h"
#include "TUri.h"
#include "TUrl.h"
#include "TUUID.h"
#include "TVersionCheck.h"
#include "TVirtualAuth.h"
#include "TVirtualFFT.h"
#include "TVirtualGL.h"
#include "TVirtualMonitoring.h"
#include "TVirtualMapFile.h"
#include "TVirtualMutex.h"
#include "TVirtualPadEditor.h"
#include "TVirtualPad.h"
#include "TVirtualPadPainter.h"
#include "TVirtualPerfStats.h"
#include "TVirtualPS.h"
#include "TVirtualQConnection.h"
#include "TVirtualRWMutex.h"
#include "TVirtualTableInterface.h"
#include "TVirtualViewer3D.h"
#include "TVirtualX.h"
#include "strlcpy.h"
#include "snprintf.h"
#include "strtok.h"
#include "root_std_complex.h"
#include "ROOT/TSeq.hxx"
#include "TArrayC.h"
#include "TArrayD.h"
#include "TArrayF.h"
#include "TArray.h"
#include "TArrayI.h"
#include "TArrayL64.h"
#include "TArrayL.h"
#include "TArrayS.h"
#include "TBits.h"
#include "TBtree.h"
#include "TClassTable.h"
#include "TClonesArray.h"
#include "TCollection.h"
#include "TCollectionProxyInfo.h"
#include "TExMap.h"
#include "THashList.h"
#include "THashTable.h"
#include "TIterator.h"
#include "TList.h"
#include "TMap.h"
#include "TObjArray.h"
#include "TObjectTable.h"
#include "TOrdCollection.h"
#include "TRefArray.h"
#include "TRefTable.h"
#include "TSeqCollection.h"
#include "TSortedList.h"
#include "TVirtualCollectionProxy.h"
#include "ESTLType.h"
#include "RStringView.h"
#include "TClassEdit.h"
#include "TError.h"
#include "ThreadLocalStorage.h"
#include "ROOT/RError.hxx"
#include "ROOT/RLogger.hxx"
#include "ROOT/RNotFn.hxx"
#include "ROOT/RRangeCast.hxx"
#include "ROOT/RSpan.hxx"
#include "ROOT/RStringView.hxx"
#include "ROOT/StringUtils.hxx"
#include "ROOT/span.hxx"
#include "ROOT/TypeTraits.hxx"
#include "GuiTypes.h"
#include "TApplicationImp.h"
#include "TBrowser.h"
#include "TBrowserImp.h"
#include "TCanvasImp.h"
#include "TClassMenuItem.h"
#include "TContextMenu.h"
#include "TContextMenuImp.h"
#include "TControlBarImp.h"
#include "TGuiFactory.h"
#include "TInspectorImp.h"
#include "TObjectSpy.h"
#include "TToggleGroup.h"
#include "TToggle.h"
#include "TBaseClass.h"
#include "TClassGenerator.h"
#include "TClass.h"
#include "TClassRef.h"
#include "TClassStreamer.h"
#include "TDataMember.h"
#include "TDataType.h"
#include "TDictAttributeMap.h"
#include "TDictionary.h"
#include "TEnumConstant.h"
#include "TEnum.h"
#include "TFileMergeInfo.h"
#include "TFunction.h"
#include "TFunctionTemplate.h"
#include "TGenericClassInfo.h"
#include "TGlobal.h"
#include "TInterpreter.h"
#include "TInterpreterValue.h"
#include "TIsAProxy.h"
#include "TListOfDataMembers.h"
#include "TListOfEnums.h"
#include "TListOfEnumsWithLock.h"
#include "TListOfFunctions.h"
#include "TListOfFunctionTemplates.h"
#include "TMemberStreamer.h"
#include "TMethodArg.h"
#include "TMethodCall.h"
#include "TMethod.h"
#include "TProtoClass.h"
#include "TRealData.h"
#include "TSchemaHelper.h"
#include "TSchemaRule.h"
#include "TSchemaRuleSet.h"
#include "TStatusBitsChecker.h"
#include "TStreamerElement.h"
#include "TStreamer.h"
#include "TVirtualIsAProxy.h"
#include "TVirtualRefProxy.h"
#include "TVirtualStreamerInfo.h"
#include "TVirtualArray.h"
#include "TVirtualObject.h"
#include "Getline.h"
#include "TUnixSystem.h"
// Extra headers
#include "ROOT/TSeq.hxx"
#include "ROOT/StringConv.hxx"
